CloneFromRef

Trait CloneFromRef 

pub trait CloneFromRef<M: Marker>: Tuple<M> {
    // Required method
    fn clone_from_ref(from: Self::Ref<'_>) -> Self;
}

Required Methods

fn clone_from_ref(from: Self::Ref<'_>) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<A, B> CloneFromRef<Many> for (A, B)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B)>, A: 'static + Clone, B: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C> CloneFromRef<Many> for (A, B, C)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D> CloneFromRef<Many> for (A, B, C, D)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D, E> CloneFromRef<Many> for (A, B, C, D, E)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D, &'x E)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone, E: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D, E, F> CloneFromRef<Many> for (A, B, C, D, E, F)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D, &'x E, &'x F)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone, E: 'static + Clone, F: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D, E, F, G> CloneFromRef<Many> for (A, B, C, D, E, F, G)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D, &'x E, &'x F, &'x G)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone, E: 'static + Clone, F: 'static + Clone, G: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D, E, F, G, H> CloneFromRef<Many> for (A, B, C, D, E, F, G, H)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D, &'x E, &'x F, &'x G, &'x H)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone, E: 'static + Clone, F: 'static + Clone, G: 'static + Clone, H: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D, E, F, G, H, I> CloneFromRef<Many> for (A, B, C, D, E, F, G, H, I)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D, &'x E, &'x F, &'x G, &'x H, &'x I)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone, E: 'static + Clone, F: 'static + Clone, G: 'static + Clone, H: 'static + Clone, I: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D, E, F, G, H, I, J> CloneFromRef<Many> for (A, B, C, D, E, F, G, H, I, J)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D, &'x E, &'x F, &'x G, &'x H, &'x I, &'x J)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone, E: 'static + Clone, F: 'static + Clone, G: 'static + Clone, H: 'static + Clone, I: 'static + Clone, J: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D, E, F, G, H, I, J, K> CloneFromRef<Many> for (A, B, C, D, E, F, G, H, I, J, K)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D, &'x E, &'x F, &'x G, &'x H, &'x I, &'x J, &'x K)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone, E: 'static + Clone, F: 'static + Clone, G: 'static + Clone, H: 'static + Clone, I: 'static + Clone, J: 'static + Clone, K: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L> CloneFromRef<Many> for (A, B, C, D, E, F, G, H, I, J, K, L)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D, &'x E, &'x F, &'x G, &'x H, &'x I, &'x J, &'x K, &'x L)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone, E: 'static + Clone, F: 'static + Clone, G: 'static + Clone, H: 'static + Clone, I: 'static + Clone, J: 'static + Clone, K: 'static + Clone, L: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M> CloneFromRef<Many> for (A, B, C, D, E, F, G, H, I, J, K, L, M)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D, &'x E, &'x F, &'x G, &'x H, &'x I, &'x J, &'x K, &'x L, &'x M)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone, E: 'static + Clone, F: 'static + Clone, G: 'static + Clone, H: 'static + Clone, I: 'static + Clone, J: 'static + Clone, K: 'static + Clone, L: 'static + Clone, M: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> CloneFromRef<Many> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D, &'x E, &'x F, &'x G, &'x H, &'x I, &'x J, &'x K, &'x L, &'x M, &'x N)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone, E: 'static + Clone, F: 'static + Clone, G: 'static + Clone, H: 'static + Clone, I: 'static + Clone, J: 'static + Clone, K: 'static + Clone, L: 'static + Clone, M: 'static + Clone, N: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> CloneFromRef<Many> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D, &'x E, &'x F, &'x G, &'x H, &'x I, &'x J, &'x K, &'x L, &'x M, &'x N, &'x O)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone, E: 'static + Clone, F: 'static + Clone, G: 'static + Clone, H: 'static + Clone, I: 'static + Clone, J: 'static + Clone, K: 'static + Clone, L: 'static + Clone, M: 'static + Clone, N: 'static + Clone, O: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> CloneFromRef<Many> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)
where Self: for<'x> Tuple<Many, Ref<'x> = (&'x A, &'x B, &'x C, &'x D, &'x E, &'x F, &'x G, &'x H, &'x I, &'x J, &'x K, &'x L, &'x M, &'x N, &'x O, &'x P)>, A: 'static + Clone, B: 'static + Clone, C: 'static + Clone, D: 'static + Clone, E: 'static + Clone, F: 'static + Clone, G: 'static + Clone, H: 'static + Clone, I: 'static + Clone, J: 'static + Clone, K: 'static + Clone, L: 'static + Clone, M: 'static + Clone, N: 'static + Clone, O: 'static + Clone, P: 'static + Clone,

Source

fn clone_from_ref(from: Self::Ref<'_>) -> Self
where Self: 'static,

Implementors

Source

impl<T> CloneFromRef<One> for T
where T: for<'x> Tuple<One, Ref<'x> = &'x T> + Clone + 'static,