TableDef

Struct TableDef 

pub struct TableDef {
    pub name: &'static str,
    pub primary_key: &'static [&'static str],
    pub values: Values,
    pub key_values: Values,
    pub other_values: Values,
    pub constraints: &'static [Constraint],
}
Definition of a Table used to generate the SQL schema

Created by the #[derive(Table)] proc-macro.

Fields

name: &'static str

Name of the table: #[derive(Table)] uses the lowercase name of the struct

primary_key: &'static [&'static str]

Names of the Columns that make up the values of the primary #[key]

This is empty if the Table has no primary key.

values: Values

Definitions and names for all constituent Values

key_values: Values

Definitions and names for all (if any) primary key Values

other_values: Values

Definitions and names for all Values that are not (part of) the primary key.

This could be empty (if all [Value']s are part of the primary key), or it could be equal to values`.

constraints: &'static [Constraint]

List of Table-level Constraints

Implementations

Source

impl TableDef

pub const fn define<const N: usize>(&self) -> StrConstrue<N>